#!/bin/bash

#Copyright (c) 2021-2024 AO MCST
#Distributed under the terms of MIT License.

# Script adds comments from devtree to sensors command output.
# Usage:
#	"lsensors" -- full output
#	"lsensors list" -- printing of found sensors
#	"lsensors <sensorname> [<sensorname> [...]]" -- print some sensors info


# Check for sensors
sensorscmd=`command -v sensors`
if [ ! -f "$sensorscmd" ]; then
	echo "ERROR: please, install lm-sensors"
	exit 1
fi

# Verbose print
verbose=1
if [ "$1" == "list" ]; then
	verbose=0
	shift
fi

# Print list of adapters
if [ "$#" -eq 0 ]; then
	# Get Adapter list
	prevline=""
	adapters=""
	while IFS= read -r line
	do
		if [[ "$line" == "Adapter:"* ]]; then
			adapters+="${prevline};"
		fi
		prevline=$line
	done < <($sensorscmd)

	myifs=$IFS
	IFS=$';'
	i=1
	for adapter in $adapters
	do
		comment=""
		if [[ "$adapter" == *"-i2c-"* ]]; then
			busaddr=`echo "$adapter" | awk -F"-" '{print "i2c-" $3 "/" $3 "-00" $4}'`
			# get hwmon name"
			IFS=$myifs
			for hwmon in `ls -1 /sys/class/hwmon`
			do
				slink=`realpath /sys/class/hwmon/$hwmon`
				if [[ "$slink" == *"$busaddr"* ]]; then
					comment=" - ${hwmon}"
					if [ -f "/sys/class/hwmon/${hwmon}/of_node/label" ]; then
						comment+=": "
						comment+=$(cat /sys/class/hwmon/${hwmon}/of_node/label | tr '\0' '\n')
					fi
				fi
			done
		fi
		if [[ $verbose -eq 1 ]]; then
			echo "--------------------------------------------------------------"
			echo "$i. ${adapter}${comment}"
			$sensorscmd -A $adapter
		else
			echo "$i. ${adapter}${comment}"
		fi
		i=$(( $i + 1 ))
	done
	exit 0
fi

# Sensors info
for adapter in $@
do
	$sensorscmd -A $adapter
done
